<?php
    if (session_status() == PHP_SESSION_NONE) {
        // If a session is not already started, start a new one
        session_start();
    }
    ob_start();
    if (!isset($_SESSION["user_id"])) {
        echo "here";
        // User is not authenticated; redirect to login page
        header("Location: login");
        ob_end_flush();
    }

    require_once (__DIR__.'/../../../Server/Controllers/PembelianController.php');
    require_once (__DIR__.'/../../../Server/Controllers/TicketController.php');
    require_once (__DIR__.'/../../../Server/Controllers/UserController.php');
    require_once (__DIR__.'/../../../Server/Controllers/EventController.php');

    $eventController = new EventController();
    $pembelianController = new PembelianController();
    $ticketController = new TicketController();
    $userController = new \Server\Controllers\UserController();

    // Handle search query
    $searchQuery = isset($_GET['search']) ? $_GET['search'] : '';
    $sortKey = isset($_GET['sort']) ? $_GET['sort'] : 'name'; 
    $minStock = isset($_GET['min_stock']) ? $_GET['min_stock'] : null;
    
    // Get search results or all events 
    $searchResults = $eventController->searchEvents($searchQuery, $sortKey, $minStock);
    if (!isset($_GET['page'])) {
        $_GET['page'] = 1;
    }
    $pageSize = isset($_GET['pageSize']) ? $_GET['pageSize'] : 10; 

    $paginationData = $eventController->paginateEvents($searchResults,$_GET['page'],$pageSize);
    $events = $paginationData['events'];
    $totalEvents = $paginationData['total'];
    $currentPage = $paginationData['page'];
    $maxPage = $paginationData['maxpage'];

    $isAdmin = $userController->getUser($_SESSION['user_id'])['isadmin'];
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>HOME • TICKET KU</title>
    <link rel="stylesheet" type="text/css" href="/../../global.css">
    <link rel="stylesheet" type="text/css" href="/../../form.css">
    <link rel="stylesheet" type="text/css" href="/../../footer.css">
    <link rel="stylesheet" type="text/css" href="/../../navbar.css">
    <link rel="stylesheet" type="text/css" href="/../../container.css">
    <link rel="stylesheet" type="text/css" href="/../../auth.css">
    <link rel="stylesheet" type="text/css" href="/../../dropdown.css">
    <link rel="stylesheet" type="text/css" href="/../../pagination.css">
    <link rel="stylesheet" type="text/css" href="/../../media.css">
</head>

<body>
<!-- Navbar -->
    <?php include (__DIR__.'/../../components/navbar.php');?>

    <div class="main-content">
        <div class="column">
            <?php if ($isAdmin) : ?>
                <button onclick="openCreateEventPage()" id="createEventBtn" class="admin">Create Event</button>
            <?php endif; ?>
            <div class="row">
                <input type="text" id="searchInput" placeholder="Search.." value="<?= isset($searchQuery) ? htmlspecialchars($searchQuery) : '' ?>" style="width:250%;">
                <select name="sort" id="sortSelect" class="styled-select">
                    <option value="" <?= empty($sortKey) ? 'selected' : '' ?>>No Sorting</option>
                    <option value="name" <?= $sortKey === 'name' ? 'selected' : '' ?>>Sort by Name</option>
                    <option value="location" <?= $sortKey === 'location' ? 'selected' : '' ?>>Sort by Location</option>
                </select>
                <!-- Change input type to "text" for minimum stock -->
                <input type="text" id="minStockInput" name="min_stock" placeholder="Min Stock" value="<?= isset($minStock) ? htmlspecialchars($minStock) : 0 ?>"
">
                <button type="submit" id="search-button">Search</button>
            </div>
            
            <?php foreach ($events as $event) :    
                include (__DIR__.'/../../components/event.php');
            endforeach;?>

            <div class="pagination">
                <?php
                $searchParams = [
                    'search' => $searchQuery,
                    'min_stock' => $minStock,
                    'sort' => $sortKey,
                    'pageSize' => $pageSize, // Include page size
                ];

                $maxButtons = 5;  // Maximum number of pagination buttons to display
                $halfMaxButtons = floor($maxButtons / 2);

                if ($currentPage > 1) : ?>
                    <a href="?page=<?= $currentPage - 1 . '&' . http_build_query($searchParams) ?>">Previous</a>
                <?php endif; ?>

                <?php
                for ($i = max(1, $currentPage - $halfMaxButtons); $i <= min($maxPage, $currentPage + $halfMaxButtons); $i++) : ?>
                    <a href="?page=<?= $i . '&' . http_build_query($searchParams) ?>" <?= ($i == $currentPage) ? 'class="active"' : '' ?>><?= $i ?></a>
                <?php endfor; ?>

                <?php if ($currentPage < $maxPage) : ?>
                    <a href="?page=<?= $currentPage + 1 . '&' . http_build_query($searchParams) ?>">Next</a>
                <?php endif; ?>
            </div>


        </div>
    </div>
    
    <?php include (__DIR__.'/../../components/footer.php');?>

    <script defer>
        function toggleMenu() {
            const navbar = document.querySelector('.navbar ul');
            navbar.classList.toggle('show');
        }

        function openCreateEventPage() {
            window.location.href = "/app/Views/event/create.php";
        }

        let debounceTimer;
        let searchInput = document.getElementById('searchInput');
        let cursorPosition = 0;

        // Initialize the cursor position
        searchInput.addEventListener('input', function () {
            cursorPosition = this.selectionStart;
        });

        function debounceSearch() {
            clearTimeout(debounceTimer);
            debounceTimer = setTimeout(function () {
                // Get the search input values
                const searchQuery = searchInput.value;
                const minStock = document.getElementById('minStockInput').value;
                const sortKey = document.getElementById('sortSelect').value;

                // Construct the URL with search, min_stock, and sort parameters
                const url = `/home?search=${encodeURIComponent(searchQuery)}&min_stock=${encodeURIComponent(minStock)}&sort=${encodeURIComponent(sortKey)}`;

                // Redirect to the updated URL
                window.location.href = url;

                // Restore focus and cursor position
                searchInput.focus();
                searchInput.setSelectionRange(cursorPosition, cursorPosition);
            }, 500); // Adjust the debounce delay as needed (in milliseconds)
        }

        // Attach the debounce function to the search input's input event
        searchInput.addEventListener('input', debounceSearch);
        document.getElementById('minStockInput').addEventListener('input', debounceSearch);
        // Attach an event listener to the sort dropdown
        document.getElementById('sortSelect').addEventListener('change', function () {
            // Trigger the debounceSearch function when the sorting option changes
            debounceSearch();
        });

        // Function to show delete confirmation dialog
        function showConfirmationDialog(eventId) {
            if (confirm("Are you sure you want to delete this event?")) {
                // If the user confirms, submit the corresponding form
                document.getElementById("deleteEventForm" + eventId).submit();
            }
        }

        // Attach the confirmation dialog to all buttons with the class "confirmDeleteBtn"
        const deleteButtons = document.querySelectorAll(".confirmDeleteBtn");
        deleteButtons.forEach(button => {
            button.addEventListener("click", function() {
                const eventId = this.getAttribute("data-eventid");
                showConfirmationDialog(eventId);
            });
        });
    </script>

</body>

</html>
