<?php

namespace Server\Models;

use PDO;

class EventModel extends Model {

    public function createEvent($event_name, $stock, $event_price, $event_date, $event_location, $gambar, $vid) {
        $success = true;

        if ($gambar !== null && isset($gambar['name']) && isset($gambar['tmp_name'])) {
            $imageFilePath = '../assets/images/' . $gambar['name'];

            if (move_uploaded_file($gambar['tmp_name'], $imageFilePath)) {
                echo "File uploaded successfully";
            } else {
                echo "Error moving file to destination";
                $imageFilePath = null; // Set to null if there's an error
            }
        } else {
            echo "No image uploaded";
            $imageFilePath = null; // Set to null if no file is uploaded
        }

        if ($vid !== null && isset($vid['name']) && isset($vid['tmp_name'])) {
            $vidFilePath = '../assets/videos/' . $vid['name'];

            if (move_uploaded_file($vid['tmp_name'], $vidFilePath)) {
                echo "File uploaded successfully";
            } else {
                echo "Error moving file to destination";
                $vidFilePath = null; // Set to null if there's an error
            }
        } else {
            echo "No video uploaded";
            $vidFilePath = null; // Set to null if no file is uploaded
        }

        if ($imageFilePath === null || $vidFilePath === null) {
            $success = false;
            return $success;
        }

        $stmt = $this->database->prepare("INSERT INTO events (event_name, event_stock, event_price, event_date, event_location, gambar, vid) VALUES (?, ?, ?, ?, ?, ?, ?)");

        if ($stmt->execute([$event_name, $stock, $event_price, $event_date, $event_location, $imageFilePath, $vidFilePath])) {
            echo "Event created successfully";
            return $success;
        } else {
            echo "Error creating event: " . print_r($stmt->errorInfo(), true);
            $success = false;
            return $success;
        }
    }

    public function updateEvent($event_id, $event_name, $event_price, $event_date, $event_location, $gambar, $vid) {
        $sql = "UPDATE events SET event_name = ?, event_price = ?, event_date = ?, event_location = ?";

        if ($gambar !== null && isset($gambar['name']) && isset($gambar['tmp_name'])) {
            $imageFilePath = '../assets/images/' . $gambar['name'];

            if (move_uploaded_file($gambar['tmp_name'], $imageFilePath)) {
                echo "File uploaded successfully<br>";
            } else {
                echo "Error moving file to destination<br>";
                $imageFilePath = null; // Set to null if there's an error
            }

            $sql .= ", gambar = ?";
        }

        if ($vid !== null && isset($vid['name']) && isset($vid['tmp_name'])) {
            $vidFilePath = '../assets/videos/' . $vid['name'];

            if (move_uploaded_file($vid['tmp_name'], $vidFilePath)) {
                echo "File uploaded successfully<br>";
            } else {
                echo "Error moving file to destination<br>";
                $vidFilePath = null; // Set to null if there's an error
            }

            $sql .= ", vid = ?";
        }

        $sql .= " WHERE event_id = ?";

        $stmt = $this->database->prepare($sql);

        $params = [$event_name, $event_price, $event_date, $event_location];

        if ($imageFilePath !== null) {
            $params[] = $imageFilePath;
        }

        if ($vidFilePath !== null) {
            $params[] = $vidFilePath;
        }

        $params[] = $event_id;

        $rowCount = $stmt->execute($params);

        if ($rowCount !== false) {
            echo "Event updated successfully. Rows affected: $rowCount";
        } else {
            echo "Error updating event: " . print_r($stmt->errorInfo(), true);
        }
        return "Event updated successfully";
    }

    public function deleteEvent($eventId) {
        try {
            // Delete associated records or perform necessary cleanup

            $stmtEvent = $this->database->prepare("DELETE FROM events WHERE event_id = ?");
            $stmtEvent->execute([$eventId]);

            echo "Event deleted successfully<br>";

            return "Event deleted successfully";
        } catch (PDOException $e) {
            echo "Error: " . $e->getMessage() . "<br>";

            return "Error: " . $e->getMessage();
        }
    }

    public function getAllEvents() {
        $stmt = $this->database->prepare("SELECT * FROM events");
        $stmt->execute();
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    public function getEvent($eventId) {
        $stmt = $this->database->prepare("SELECT * FROM events WHERE event_id = ?");
        $stmt->execute([$eventId]);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }

    public function getLastEventId() {
        $stmt = $this->database->prepare("SELECT event_id FROM events ORDER BY event_id DESC LIMIT 1");
        $stmt->execute();
        return $stmt->fetch(PDO::FETCH_ASSOC)['event_id'];
    }

    public function searchEvents($searchQuery, $sortKey, $minStock) {
        try {
            if ($minStock == null) {
                $minStock = 0;
            }
    
            $stmt = "SELECT * FROM events 
                     WHERE (LOWER(event_name) LIKE LOWER(?) OR LOWER(event_location) LIKE LOWER(?)) 
                     AND event_stock >= ?";
    
            if (!empty($sortKey)) {
                $stmt .= " ORDER BY ";
    
                if ($sortKey === 'name') {
                    $stmt .= "event_name ASC";
                } elseif ($sortKey === 'location') {
                    $stmt .= "event_location ASC";
                } 
            }
    
            $query = $this->database->prepare($stmt);
            $query->execute(array('%'.$searchQuery.'%', '%'.$searchQuery.'%', $minStock));
    
            return $query->fetchAll(PDO::FETCH_ASSOC);
        } catch (PDOException $e) {
            throw new Exception("Error searching events: " . $e->getMessage());
        }
    }
    
}
