<?php

namespace Server\Models;

use PDO;

include (__DIR__."/Model.php");


class UserModel extends Model {
    public function createUser($name, $username, $email, $hashedPass, $isAdmin) {
        $response = [
            'success'=> true,
            'message'=> ''
        ];
    
        try {
            $stmt = $this->database->prepare("INSERT INTO users (user_name, username, user_email, user_hashedPass, isAdmin) VALUES (?, ?, ?, ?, ?)");
            $stmt->execute([$name, $username, $email, $hashedPass, $isAdmin]);
            $response['message'] = "User created successfully";
            return $response;
        } catch (PDOException $e) {
            $response['success'] = false;
            // Check if the error code corresponds to a unique constraint violation.
            if ($e->getCode() === '23000') {
                // Handle the error as a duplicate entry.
                $response['message'] = "Username or email already exists. Please choose a different one.";
                return $response;
            } else {
                // Handle other database errors.
                $response['message'] = "Database error: " . $e->getMessage();
                return $response;
            }
        }
    }
    

    // User.php
    public function getUser($userId) {
        $stmt = $this->database->prepare("SELECT * FROM users WHERE user_ID = ?");
        $stmt->execute([$userId]);

        if ($stmt) {
            $userData = $stmt->fetch(PDO::FETCH_ASSOC);

            // Check if user data is found
            if ($userData) {
                return $userData;
            } else {
                return null;
            }
        } else {
            return null;
        }
    }

    public function getUserByEmail($email) {
        $stmt = $this->database->prepare("SELECT * FROM users WHERE user_email = ?");
        $stmt->execute([$email]);

        return $stmt->fetch(PDO::FETCH_ASSOC);
    }

    public function getUserByUsername($username){
        $stmt = $this->database->prepare("SELECT * FROM users WHERE username = ?");
        $stmt->execute([$username]);

        return $stmt->fetch(PDO::FETCH_ASSOC);
    }

    public function updateUser($userId, $name, $username, $email, $hashedPass, $isAdmin) {
        $stmt = $this->database->prepare("UPDATE users SET user_name = ?, username = ?, user_email = ?, user_hashedPass = ?, isAdmin = ? WHERE user_ID = ?");
        $stmt->execute([$name, $username, $email, $hashedPass, $isAdmin, $userId]);

        return "User updated successfully";
    }

    public function editProfile($userId, $name, $username, $email) {
        $stmt = $this->database->prepare("UPDATE users SET user_name = ?, username = ?, user_email = ? WHERE user_id = ?");
        return $stmt->execute([$name, $username, $email, $userId]);
    }

    public function deleteUser($userId) {
        $stmt = $this->database->prepare("DELETE FROM users WHERE user_ID = ?");
        $stmt->execute([$userId]);

        return "User deleted successfully";
    }

    public function getAllUsers() {
        $stmt = $this->database->query("SELECT * FROM users");
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
}
?>
