<?php

declare(strict_types=1);

include (__DIR__."/Router/Router.php");
include (__DIR__."/Controllers/UserController.php");
include (__DIR__."/Controllers/EventController.php");
include (__DIR__."/Controllers/HomeController.php");

$router = new \Server\Router\Router();

function checkLoggedIn(): bool {
    if (session_status() == PHP_SESSION_NONE) {
        // If a session is not already started, start a new one
        session_start();
    }
    return isset($_SESSION['user_id']);
}

$router->get('/', function() {
    header('Location: /home');
    exit();
});

// Routes for HomeController
$router->get('/home', [new \Server\Controllers\HomeController(),'home']);

// Routes for UserController
$router->get('/register', [new \Server\Controllers\UserController(), 'registerview']);
$router->post('/register', [new \Server\Controllers\UserController(), 'register']);
$router->post('/register/search-email', [checkLoggedIn(), [new \Server\Controllers\UserController(), 'findEmail']]);
$router->post('/register/search-username', [checkLoggedIn(), [new \Server\Controllers\UserController(), 'findByUsername']]);
$router->get('/login', [new \Server\Controllers\UserController(), 'loginview']);
$router->post('/login', [new \Server\Controllers\UserController(), 'login']);
$router->post('/logout', function() {
    // No need to checkLoggedIn() here, as users can access this even if not logged in
    if (session_status() == PHP_SESSION_NONE) {
        // If a session is not already started, start a new one
        session_start();
    }
    session_destroy();
    header('Location: /login');
    exit();
});
$router->post('/profile', [checkLoggedIn(), [new \Server\Controllers\UserController(), 'viewProfile']]);
$router->post('/profile/edit', [checkLoggedIn(), [new \Server\Controllers\UserController(), 'editProfile']]);

// Routes for EventsController
// $router->get('/events', [checkLoggedIn(), [new \Server\Controllers\EventController(), 'eventList10view']]);
// $router->post('/events/create', [checkLoggedIn(), [new \Server\Controllers\EventController(), 'createEvent']]);
// $router->post('/events/update', [checkLoggedIn(), [new \Server\Controllers\EventController(), 'updateEvent']]);
// $router->post('/events/delete', [checkLoggedIn(), [new \Server\Controllers\EventController(), 'deleteEvent']]);
// $router->get('/events/search', [checkLoggedIn(), [new \Server\Controllers\EventController(), 'searchview']]);

$router->run();
